@@ -860,7 +860,7 @@ void BackwardsWalker::backwardsMap()
                 pairedNodeDir = !pairedDir;
 
             //Does paired node belong to history ?
-            if (G->nodesTab[pairedNode].isTraversed(pairedNodeDir) == 0)
+            if (G->nodesTab[pairedNode].isVisited(pairedNodeDir) == 0)
                 continue;
 
             //get the corresponding(s) BSnodes
