@@ -34,8 +34,12 @@ public:
 private:
     
     vector<unsigned int> ePath;
+    size_t p1; //two pointer on ePath that indicates the boundaries for either
+    size_t p2; //desired amplicon or PE matches counts
     vector<unsigned int> pathNode;
     vector<bool> pathDir;
+    string nodeList;
+    
     unsigned int nodeID;
     bool nodeDir;
     vector<string> args;
@@ -71,6 +75,10 @@ private:
     void printReadsLayout();
     void locateRead();
     void setCheckDistances();
+    void p3(); //get input for primer3 website
+    bool set_p1p2_ePath(); //from args(1)
+    void dev();
+    
 
     
 
