@@ -437,14 +437,14 @@ int main(int argc, char **argv) {
             truncateReads = minRl;
         }
 
-        int readLength = 0;
-
         if (truncateReads > minRl) {
             cout << "Adjusting reads truncation to " << minRl << endl;
             truncateReads = minRl;
         }
 
         cout << "Reads layout initialization... ";
+        nReadsEstimation += nReadsEstimation*.1; //10% more
+        
         L->init(R, nReadsEstimation);
         R->init(nReadsEstimation, minRl);
         cout << "done" << endl;
@@ -507,10 +507,13 @@ int main(int argc, char **argv) {
             minOverlapMatch = R->getReadsLength() / 2;
         R->setMinOvSize(minOverlapMatch);
 
-       
-    
         G.computeOverlaps(nThreads);
-        G.removeTransitiveEdges(); 
+        G.removeTransitiveEdges();
+        
+        //        
+        // DEV write a raw overlap file
+        //    G.saveData( (prefix + ".ovlT").c_str() );
+
         G.countEdges();
 
         if (checkGraph)
@@ -522,7 +525,7 @@ int main(int argc, char **argv) {
         //    devShell(&G, R, P, L);
 
 
-        if (!G.saveData((prefix + ".ovl").c_str())) {
+         if (!G.saveData((prefix + ".ovl").c_str())) {
             cout << "Problem writing the .ovl file\n";
         }
 
@@ -551,11 +554,13 @@ int main(int argc, char **argv) {
         cout << "   minimum overlap size:     " << G.getMinOverlap() << '\n';
  
         if (overlapCutoff != 0) {
-            if (overlapCutoff > R->getReadsLength()-1)
+            if (overlapCutoff > R->getReadsLength()-1 || overlapCutoff < G.getMinOverlap())
             {
-                overlapCutoff = R->getReadsLength()-1;
-                cout << "overlap cutoff cannot exceed the reads length.\n";
-                cout << "it has been adjusted" << endl;
+                cerr << "improper overlaps cutoff value (-m)\n";
+                cerr << "possible values are in the range ["
+                        << G.getMinOverlap() << ";"
+                        << R->getReadsLength()-1 << "]" << endl;
+                exit(0);
             }
             cout << "Discarding overlaps shorter than " << overlapCutoff << "... " << flush;
             G.overlapSizeCutoff(overlapCutoff);
