@@ -610,7 +610,7 @@ void OverlapsGraph::condense(bool verbose, bool sortEdges)
 //        if (nodesTab[i].isDiscarded() && nodesTab[i].getNOverlap()==0)
 //            continue;
         
-        if (!nodesTab[i].isTraversed())
+        if (!nodesTab[i].isVisited())
         {
             nConcatenatedNodes = nodesTab[i].getLongestNonAmbiguousPath(
                                                                         concatSeq,
@@ -939,8 +939,7 @@ unsigned int OverlapsGraph::removeEdgesByValue(float suspectCutoff, float GIncoh
 //            cout << setprecision(2) << "Contextual cleaning: step2..."
 //            << (double) 100 * i / nNodes
 //                << "%           \r" << flush;
-        if (i==90)
-            cout << "";
+       
         nRemoved += nodesTab[i].removeEdgesByValue(suspectCutoff,GIncoherentCutoff);
     }
     
@@ -951,7 +950,6 @@ unsigned int OverlapsGraph::removeEdgesByValue(float suspectCutoff, float GIncoh
     
     cout << "Contextual cleaning: step2... done                 " << endl;
     return nRemoved / 2; //self overlap do not have reciprocal edges !!
-
 }
 
 void OverlapsGraph::overlapSizeCutoff(unsigned int cutoff)
@@ -996,7 +994,7 @@ void OverlapsGraph::removeTransitiveEdges()
     {
         if (i % 1000 == 0)
         {
-            cout << "Flagging transitive edges..." << (int) (((float) i / nNodes)*100) << "%\r" << flush;
+            cerr << "Flagging transitive edges..." << (int) (((float) i / nNodes)*100) << "%\r" << flush;
         }
 
    //     flagged.clear();
@@ -1029,7 +1027,7 @@ void OverlapsGraph::removeTransitiveEdges()
     {
         if (i % 1000 == 0)
         {
-            cout << "Removing flagged edges..." << (int) (((float) i / nNodes)*100) << "%\r" << flush;
+            cerr << "Removing flagged edges..." << (int) (((float) i / nNodes)*100) << "%\r" << flush;
         }
         nodesTab[i].removeMarkedEdge();
     }
@@ -1506,7 +1504,7 @@ void OverlapsGraph::estimatePairedDistance(unsigned int horizon, double nsd, str
         if (min<0)
             min=0;
         
-        if (nCounted == 0)
+        if (nCounted < 20)
             min=max=0;
         
         //bounded sample (mean +- nsd*sd)
@@ -1936,7 +1934,7 @@ void OverlapsGraph::assemble(
 
     cout << "Number of contigs:  " << contigCount << endl;
     stats(echant.begin(), echant.end(), cout);
-    cout << "Contigs elongations were stopped due to:\n";
+    cout << "Assembly breaks occurred due to:\n";
     cout << "   branching: " << nBranching << "\n";
     cout << "   dead-end:  " << nNoOv << "\n";
 
@@ -2000,10 +1998,10 @@ string OverlapsGraph::ePathToSeq(const vector<unsigned int> &path)
         return "";
     else if (path.size() == 2)
     {
-        if (path[0]==0)
-            return nodesTab[path.at(1)].getDirectSequence();
-        else if (path[0]==1)
+        if (path[0]==1)
             return nodesTab[path.at(1)].getDirectSequence();
+        else if(path[0]==0)
+            return nodesTab[path.at(1)].getReverseSequence();
         else
         {
             cout << "OverlapsGraph::ePathToSeq(...) problem\n";
@@ -2095,8 +2093,8 @@ unsigned int OverlapsGraph::getNReadsInEPath(const vector<unsigned int> &path)
 
 void OverlapsGraph::nodeListToEPath(string args, vector<unsigned int> &ePath)//for DEV mode
 {
-    //only return a string if the path is valid and unambiguous
-    //returns "" otherwise
+    //return an empty ePath is the stringPath is not valid in G
+   
     ePath.clear();
     vector<string> nodesStr;
     vector<unsigned int> nodeList;
@@ -2255,7 +2253,7 @@ void OverlapsGraph::nodePathToEPath(const vector<unsigned int> &nodePath, const
         
         found = false;
         while (nIt1.getNext(nItNext)!=0)
-        { 
+        { //check for multiple edges between two nodes (rare)
             if (nItNext == nIt2)
             {
                 if (found == true)//ambiguous seq
