@@ -47,12 +47,19 @@ void ReadsLayout::init(ReadsStorage *r, unsigned int n) {
     R = r;
     tabSize = n;
     try {
-        lastIdentical = new unsigned int[tabSize];
-        next = new unsigned int[tabSize];
-        previous = new unsigned int[tabSize];
-        nodeId = new unsigned int[tabSize];
-        position = new int[tabSize];
-        flags = new unsigned char[tabSize];
+
+        lastIdentical = (unsigned int*) malloc((tabSize) * sizeof (unsigned int));
+        next = (unsigned int*) malloc((tabSize) * sizeof (unsigned int));
+        previous = (unsigned int*) malloc((tabSize) * sizeof (unsigned int));
+        nodeId = (unsigned int*) malloc((tabSize) * sizeof (unsigned int));
+        position = (int*) malloc((tabSize) * sizeof (int));
+        flags = (unsigned char*) malloc((tabSize) * sizeof (unsigned char));
+        //        lastIdentical = new unsigned int[tabSize];
+        //        next = new unsigned int[tabSize];
+        //        previous = new unsigned int[tabSize];
+        //        nodeId = new unsigned int[tabSize];
+        //        position = new int[tabSize];
+        //        flags = new unsigned char[tabSize];
     } catch (bad_alloc ex) {
         cout << ex.what() << "\nnot enough memory. ReadsLayout::init(STReads *r)" << '\n';
         exit(0);
@@ -68,26 +75,32 @@ void ReadsLayout::init(ReadsStorage *r, unsigned int n) {
 void ReadsLayout::cleanMemory() {
     
     if (next != 0x0) {
-        delete [] next;
+     //   delete [] next;
+        free(next);
         next = 0x0;
     }
     if (previous != 0x0) {
-        delete [] previous;
+     //   delete [] previous;
+        free(previous);
         previous = 0x0;
     }
     if (nodeId != 0x0) {
-        delete [] nodeId;
+     //   delete [] nodeId;
+        free(nodeId);
         nodeId = 0x0;
     }
     if (position != 0x0) {
-        delete [] position;
+     //   delete [] position;
+        free(position);
         position = 0x0;
     }
     if (lastIdentical != 0x0) {
-        delete [] lastIdentical;
+  //      delete [] lastIdentical;
+        free(lastIdentical);
         lastIdentical = 0x0;
     }
     if (flags != 0x0) {
+    //    free(flags);
         delete [] flags;
         flags = 0x0;
     }
