@@ -85,7 +85,7 @@ void ReadsStorage::init(unsigned int upperBoundSize, unsigned int rl)
      if (upperBoundSize==0 || rl==0)
         return;
     readsLength=rl;
-    nReadsUpperBound=upperBoundSize;
+    nReadsUpperBound = upperBoundSize;
     nNR_reads = upperBoundSize;
     effectiveNReads = upperBoundSize;
     nDiscardedReads = 0;
@@ -773,6 +773,7 @@ int ReadsStorage::loadReadsFiles(
             clean2 = toUpperAndCheckDNA(s2);
         
         nrId1=nrId2=0;
+        
         if (clean1)
         {
             id1 = insertRead(s1);
@@ -800,7 +801,7 @@ int ReadsStorage::loadReadsFiles(
                 if (isDuplicateMate(nrId1, nrId2))
                 {
                     nDuplicate++;
-                    effectiveNReads -= 2; //to check but should be ok
+                    effectiveNReads -= 2;
                     dupInsert = true;
                 }
             }
